@@ -3,7 +3,7 @@ import os
 import sys
 
 
-def neglect(test):
+def neglect(test,cur):
     ci, afsp = 0, 4
     f2=open("test1.py",'w')
     f1=open(test,'r')
@@ -72,7 +72,7 @@ def neglect(test):
         f3=open("error.txt",'r')
     else:
         os.remove('test1.py')
-        os.system('python test.py')
+        os.system('python '+test)
 
         exit(0)
 
@@ -87,7 +87,7 @@ def neglect(test):
             f3.close()
             os.remove('error.txt')
             os.remove('test1.py')
-            os.system('python test.py')
+            os.system('python '+test)
             exit(0)
 
         for t in range(len(ex)):
@@ -118,5 +118,5 @@ def neglect(test):
     f7=open("error.txt",'w')
     f7.write(" ")
     f7.close()
-    os.system('python '+ __file__)
+    os.system('python '+ cur)
 
